<?php
namespace Neuron\Person\Controller\Api;
use Neuron\Access\Session;

class Controller_del extends \Neuron\Mvc\Controller {

    protected $_SESSION;
    const CODE_FIELD_REQUIRED  = 400;
    const CODE_UNAUTHORIZED = 401;
    const CODE_SESSION_EXPIRED = 403;



	public function onDispatch(\Zend\Mvc\MvcEvent $e) {

        /* dispatch NAF - v1 */
        if (class_exists('Neuron\Application\Framework\Hook\Manager')) {
            if ($manager = \Neuron\Application\Framework\Hook\Manager::get()) {
                return $manager->trigger()->onDispatch($this, parent::onDispatch($e));
            }
        }
        return parent::onDispatch($e);

        /* alternative */
        return \Neuron\Application\Framework\Event\Trigger::onDispatch($this, parent::onDispatch($e));
    }

	protected function getPostParams() {

		$request = $this->getRequest();
		if ($request->isPost()) {
			$post = $this->getRequest()->getPost();
		} else {
			$post = $this->getRequest()->getQuery();
		}

		return $post;
	}

	public function getSession($start = true) {

        $config = $this->getConfig();
        $sess_lifetime = $config['session']['gc_maxlifetime'];
        $remember = $config['session']['remember'];
        $tableSession = $config['tables']['sessions'];

        // print_r($tableSession); die();

        if(class_exists('Neuron\Application\Framework\Entity')) {
            $this->_SESSION = \Neuron\Application\Framework\Entity::get($this)->session();

            $lang = $this->_SESSION->get('lang');
            if(!isset($lang)) {
                $this->_SESSION->put(null, ['lang' => 'en_US'] );
            }

            $ref = ''.$this->_SESSION->get('ref_id');

            if ($this->_SESSION->owner() && (strlen($ref) < 1)) {
                // User Role
                $user = \Neuron\Application\Framework\Entity::get($this)->user();
                $grants = $user->grants->load();
                $roles = $user->roles->load($grants->data);

                // Mapper User
                $user_id =  $this->_SESSION->get('user_id');
                $GetMapperPerson = $this->GetMapPerson($user_id);
                $this->_SESSION->put(null, $GetMapperPerson);

            }

        } else {

            if ($this->_SESSION === null) {
                // $this->_SESSION = Session::factory($this->getConfig(), $this->getDb(), $start);
                $this->_SESSION = new Session('hrmisv2', Session::MODE_DATABASE,
                                                array('adapter'=>$this->getDb(),
                                                        'table'=>$tableSession,
                                                        'lifetime' => $sess_lifetime,
                                                        'remember' => $remember));
                $this->_SESSION->start(false);
                $this->_SESSION->put(null, ['lang' => 'en_US'] );
            }
            
        }

        //Set Lang
        $s = $this->_SESSION->get();
        $this->getTranslator($s['lang']);

        /* return session */
        return $this->_SESSION;
    }

    protected function isLoggedIn() {

        $session = $this->getSession();
        $owner = $session->owner();
        if (isset($owner) && !empty($owner)) {
            if ($owner != null) {
                $config = $this->getConfig();
                if($session->get('remember')){
                    $sess_lifetime = $config['session']['remember'];
                }else{
                    $sess_lifetime = $config['session']['gc_maxlifetime'];
                }

                
                if ((null !== $session->get('LAST_ACTIVITY')) && (time() - $session->get('LAST_ACTIVITY') > $sess_lifetime)) {
                    $session->stop();
                    return false;
                    //$this->redirect()->toRoute('login');
                    //echo '<script>location.href="/login";</script>';
                }
                $session->put('LAST_ACTIVITY', time());
                
                return $session;
            }
        }
        $session->stop();
        //$this->redirect()->toRoute('login');
        return false;
        //echo '<script>location.href="/login";</script>';
        //return $this->getResponse(); 
    }

    public function getTranslator($lang = 'id_ID') {
        $loc = $this->getServiceLocator();
        $translator = $loc->get('translator');
        $translator->addTranslationFile("phparray",
                     __DIR__ .'/../../language/'.$lang.'.php');
         
        //attach
        $loc->get('ViewHelperManager')->get('translate')
                                      ->setTranslator($translator);
    }

    public function GetMapPerson($user_id = 0) {
        $output = [];

        $storage = \Neuron\Person\Entity\Storage::factory($this->getDb(), $this->getConfig());
        $cpersons = new \Neuron\Person\Entity($storage);

        $dataPerson = $cpersons->loadMap($user_id,'user_id');

        return $dataPerson;

    }

    public function getOutput($json) {

        $response = $this->getResponse();
        $response->getHeaders()->addHeaderLine('Content-Type', 'application/json');
        $response->setContent($json);
        return $response;
    }

    public function publish() {

        if (class_exists('Neuron\Application\Framework\Entity')) {
            \Neuron\Application\Framework\Entity::publish();
        }
    }

    public function getUserPerson($user){
        $user_id = $user->id; 
        $dataPerson = $this->GetMapPerson($user_id);
        $dataUser = $user->pull();

        return array('user'=>$dataUser, 'person'=>$dataPerson);
    }

    public function getDataFromUrl($url, $params) {

        $output = [];

        $config = $this->getConfig();

        // API MAPPER PERSON
        $curlSession = curl_init();
        curl_setopt($curlSession, CURLOPT_URL, $config['api_url'][$url]);
        curl_setopt($curlSession, CURLOPT_POSTFIELDS, 'data='.$params);
        curl_setopt($curlSession, CURLOPT_BINARYTRANSFER, true);
        curl_setopt($curlSession, CURLOPT_RETURNTRANSFER, true);

        $jsonData = json_decode(curl_exec($curlSession));
        curl_close($curlSession);

        $data = @$jsonData->data;

        return json_decode(json_encode($data), true);

    }
	
	public function writeLogAction($param) {
	
		$result = new \Neuron\Generic\Result();
	
		if(class_exists('Neuron\Event\Log')) { 
			$cfg = $this->getConfig();
			
			//on off log
			$off = array_key_exists('writelog', $cfg) ? $cfg['writelog'] : 'on';
			if ($off != 'off') {
				$log = new \Neuron\Event\Log(\Neuron\Event\Log\Storage::factory(null, $cfg));
				$log->write(array(
					// 'event_type_id' => isset($param['event_type_id']) ? $param['event_type_id'] : '',
					// 'event_status_id' => isset($param['event_status_id']) ? $param['event_status_id'] : '',
					'subject' => isset($param['subject']) ? $param['subject'] : '',
					'identity' => isset($param['identity']) ? $param['identity'] : '',
					'time' => date("Y-m-d H:i:s",time()),
					'name' => isset($param['name']) ? $param['name'] : '',
					'description' => isset($param['description']) ? $param['description'] : '',
					'request' => isset($param['request']) ? $param['request'] : '',
					'response' => isset($param['response']) ? $param['response'] : '',
					'data1' => isset($param['data1']) ? $param['data1'] : '',
					'data2' => isset($param['data2']) ? $param['data2'] : '',
					'data3' => isset($param['data3']) ? $param['data3'] : '',
					/* Optional */
					'details' => array(
						array(
							'event_status_id' => isset($param['event_status_id']) ? $param['event_status_id'] : '',
							'event_status_id_old' => isset($param['event_status_id_old']) ? $param['event_status_id_old'] : '',
							'description' => isset($param['description']) ? $param['description'] : '',
							'data1' => isset($param['data1']) ? $param['data1'] : '',
							'data2' => isset($param['data2']) ? $param['data2'] : ''
						)
					)
				/* Optional */
				));
			}
			
        }
        return $result;
	}

}
